Class: PicoPhone::PhoneNumberMatch

Inherits:
Object
  • Object
show all
Defined in:
lib/pico_phone/phone_number.rb

Overview

Represents a single phone number match found by find_numbers.

Instance Method Summary collapse

Instance Method Details

#end_indexInteger

Exclusive byte offset of the match end within the searched text. The matched substring is text.

Returns:

  • (Integer)


111
# File 'lib/pico_phone/phone_number.rb', line 111

def end_index; end

#numberPhoneNumber

The parsed phone number.

Returns:



119
# File 'lib/pico_phone/phone_number.rb', line 119

def number; end

#raw_stringString

The substring of the searched text that was matched.

Returns:

  • (String)


115
# File 'lib/pico_phone/phone_number.rb', line 115

def raw_string; end

#startInteger

Byte offset of the match start within the searched text.

Returns:

  • (Integer)


106
# File 'lib/pico_phone/phone_number.rb', line 106

def start; end