Class: PicoPhone::PhoneNumberMatch
- Inherits:
-
Object
- Object
- PicoPhone::PhoneNumberMatch
- Defined in:
- lib/pico_phone/phone_number.rb
Overview
Represents a single phone number match found by find_numbers.
Instance Method Summary collapse
-
#end_index ⇒ Integer
Exclusive byte offset of the match end within the searched text.
-
#number ⇒ PhoneNumber
The parsed phone number.
-
#raw_string ⇒ String
The substring of the searched text that was matched.
-
#start ⇒ Integer
Byte offset of the match start within the searched text.
Instance Method Details
#end_index ⇒ Integer
Exclusive byte offset of the match end within the searched text. The matched substring is text.
111 |
# File 'lib/pico_phone/phone_number.rb', line 111 def end_index; end |
#number ⇒ PhoneNumber
The parsed phone number.
119 |
# File 'lib/pico_phone/phone_number.rb', line 119 def number; end |
#raw_string ⇒ String
The substring of the searched text that was matched.
115 |
# File 'lib/pico_phone/phone_number.rb', line 115 def raw_string; end |
#start ⇒ Integer
Byte offset of the match start within the searched text.
106 |
# File 'lib/pico_phone/phone_number.rb', line 106 def start; end |